@@ -127,6 +127,7 @@ send_spawned (DBusConnection *connection, gboolean succeeded, char *error_messag
     _g_dbus_oom ();
     
   dbus_connection_send (connection, message, NULL);
+  dbus_message_unref (message);
   /* Make sure the message is sent */
   dbus_connection_flush (connection);
 }
@@ -142,6 +143,10 @@ daemon_parse_args (int argc, char *argv[], const char *default_type)
       argc--;
       argv++;
     }
+  else if (g_getenv ("GVFS_DEBUG"))
+    {
+      print_debug = TRUE;
+    }
   
   mount_spec = NULL;
   if (argc > 1 && strcmp (argv[1], "--spawner") == 0)
